## Testing pyicon

### Testing with `quickstart`-scripts

Some first tests can be done by running the `quickstart` scripts:

```bash
cd pyicon/quickstart
./00_do_all.sh
```

This has the advantage that also necessary files (like grid files and example data) for running other tests are downloaded.

### pytest

Basic tests can be run with `pytest`:

```bash
cd pyicon
pytest
```

**Warning:** Currently, pytest fails if not the `quickstart`-scripts applied first and the example data is downloaded.

### Testing the documentation

Note that a successful test of the documentation require to install `pyicon/requirements_documentation.txt` via:

```bash
cd pyicon
pip install -r requirements_documentation.txt
```


### Docker testing container

A testing environment can be setup with docker. Therefore, save the following `Dockerfile_pyicon_testing` somewhere:

```bash
# Use the Mamba-based Miniconda image
FROM mambaorg/micromamba:1.5.5

# Temporarily switch to root to install system dependencies
USER root

# Set working directory
WORKDIR /home/user/pyicon

# Install git (if not already installed)
RUN apt-get update && apt-get install -y git && rm -rf /var/lib/apt/lists/*
RUN apt-get update && apt-get install -y \
    vim \
    wget \
    make \
    pandoc \
    rsync

# Install system dependencies needed for Cartopy, Zarr, and Dask
RUN apt-get update && apt-get install -y \
    libproj-dev \
    libgeos-dev \
    libgdal-dev \
    && rm -rf /var/lib/apt/lists/*

# Create a new environment with Python 3.11, Cartopy, Zarr, and Dask from the Conda-Forge channel
RUN micromamba create -y -n pyicon_py311_min -c conda-forge \
    python=3.11 \
    cartopy \
    zarr \
    dask[complete] && \
    micromamba clean --all --yes

# Ensure the environment is used by default
ENV PATH="/opt/conda/envs/pyicon_py311_min/bin:$PATH"

# Set color for ls
RUN echo "alias ls='ls --color=auto'" >> /etc/profile
RUN echo "alias ls='ls --color=auto'" >> /root/.bashrc

# Set default shell to bash
SHELL ["/bin/bash", "-c"]

# Define the entry point (change as needed)
CMD ["/bin/bash"]
```

Install the docker container with:

```bash
docker build -t pyicon_testing -f Dockerfile_pyicon_testing .
```

And then start it with:

```bash
docker run --rm -v ~/pyicon:/home/user/pyicon -it pyicon_testing
```

Then install pyicon:

```bash
pip install -e .
```

Now, run the `quickstart` scripts to download some example data and do already some testings:

```bash
cd quickstart
./00_do_all.sh
```

Finally, pyicon can be tested with `pytest`.